
/**
 * @file crystal.h
 * @brief Hardware timer module header
 *
 * Smart watch - CRYSTAL
 * CRYSTAL CLOCK module
 *
 * This module is used to configure the
 * CRYSTAL CLOCK 16MHz/100kbps, modify tick states and give a source clock
 *
 * crystal.h
 * Function that allows initializing the hardware timer module, using either an external crystal,
 * and sets the interrupt routine
 *
 * @authors Leonardo Martnez <leonardo.martinez.hornak@fing.edu.uy>, Isabel Morales <imorales@fing.edu.uy>
 * @version 1.0
 * @date 18 Mayo 2021
 */

#ifndef INCLUDE_CRYSTAL_H_
#define INCLUDE_CRYSTAL_H_

/**
* Constants shared with other modules
*/
#define LED1 (0x0001)
#define TICK_COUNT_LIMIT 1 //Initial value for tick count limit

/**
 * @brief Initialization routing for hardware timer using external crystal as clock source
 *
 */
void initCrystal(void);

/**
 * @brief Initialization routing for hardware timer using VLO as clock source
 *
 */
void initI2CCrystal(void);

/**
 * @brief Set the maximum number of times for ticks to trigger a function in the ISR
 * @param int times: Number of ticks to set as limit
 *
 */
void setTimerTickLimit(int times);

/**
 * @brief Get the current number of ticks
 * @return int times: Number of ticks
 *
 */
int getCurrentTick(void);

/**
 * @brief Sets callback function to be added from this module to the function queue
 * @param void* callback_function: function to be called every completed configured cycle ~250ms
 *
 */
void setCrystalISRCallbackFunction(void *callback_function);



#endif /* INCLUDE_CRYSTAL_H_ */
