/**
 * @file timer.h
 * @brief TIMER Module header
 *
 * This module groups the functions which perform time management
 * in hours, minutes, seconds and milliseconds
 *
 * timer.h
 * Time function which allows initializing a timer variable configuring it and
 * obtaining its current value
 *
 * @authors Leonardo Martnez <leonardo.martinez.hornak@fing.edu.uy>, Isabel Morales <imorales@fing.edu.uy>
 * @version 1.0
 * @date May 18, 2021
 */

#ifndef INCLUDE_TIMER_H_
#define INCLUDE_TIMER_H_

/**
* Constants shared with other modules
*/
#define TIME_INCREMENT        250        // Milliseconds used to increment the timer
#define MAX_MILISECONDS       1000       // Maximum value for milliseconds
#define MAX_SECONDS           60         // Maximum value for seconds
#define MAX_MINUTES           60         // Maximum value for minutes
#define MAX_HOURS             24         // Maximum value for hours

 /**
  * Define structure type for the time
  */
typedef struct{
    int hours;
    int minutes;
    int seconds;
    int miliseconds;
} time_t;

 /**
  * @brief Set defined time variable
  * @param time_t t: Variable of type struct time_t
  */
void set_time(time_t t);

 /**
  * @brief Obtaining time by reference
  * @param time_t *t: Pointer to the time structure
  */
void get_time(time_t *t);

 /**
  * @brief Increments time by TIME_INCREMENT
  */
void inc_time(void);

#endif /* INCLUDE_TIMER_H_ */
