/**
 * @file user_interface.h
 * @brief User Interface Module header
 *
 * Proyecto Smart Watch - User Interface
 * User Interface module
 *
 * This module is used to implement
 * the user interface of the smart watch.
 * This means, setting the states of the LEDs and
 * reacting to interrupts from the buttons. It behaves as an interface between
 * the smartwatch and the hardware dependent module
 *
 * user_interface.h
 * Modules that allows the configuration of the LEDs and getting the state of the
 * buttons.
 *
 * @authors Leonardo Martínez <leonardo.martinez.hornak@fing.edu.uy>, Isabel Morales <imorales@fing.edu.uy>
 * @version 1.0
 * @date May 15, 2021
 */

#ifndef INCLUDE_USER_INTERFACE_H_
#define INCLUDE_USER_INTERFACE_H_

/**
* Constants shared with other modules
*/

/**
 * @brief Initializes the UI, for example, setting callback function for when
 * the button is pressed
 */
void initializeUserInterface(void);

/**
 * @brief Turns on device alarm LED
 */
void turnOnAlarmLED(void);

/**
 * @brief Turns off device alarm LED
 */
void turnOffAlarmLED(void);

/**
 * @brief Turns on debug LED
 */
void turnOnDebugLED(void);

/**
 * @brief Turns off debug LED
 */
void turnffDebugLED(void);

#endif /* INCLUDE_USER_INTERFACE_H_ */
